@@ -231,6 +231,10 @@ class DiskSpaceCollector(diamond.collector.Collector):
                 raise NotImplementedError("platform not supported")
 
             for unit in self.config['byte_unit']:
+                metric_name = '%s.%s_percentfree' % (name, unit)
+                metric_value = float(blocks_free) / float(
+                    blocks_free + (blocks_total - blocks_free)) * 100
+                self.publish_gauge(metric_name, metric_value, 2)
 
                 metric_name = '%s.%s_used' % (name, unit)
                 metric_value = float(block_size) * float(
@@ -253,6 +257,9 @@ class DiskSpaceCollector(diamond.collector.Collector):
                     self.publish_gauge(metric_name, metric_value, 2)
 
             if os.name != 'nt':
+                self.publish_gauge(
+                    '%s.inodes_percentfree' % name,
+                    float(inodes_free) / float(inodes_total) * 100)
                 self.publish_gauge('%s.inodes_used' % name,
                                    inodes_total - inodes_free)
                 self.publish_gauge('%s.inodes_free' % name, inodes_free)
